==> aria2_1.12.0.orig.tar.bz2: aria2-1.12.0/src/ShareRatioSeedCriteria.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "ShareRatioSeedCriteria.h"
#include "DownloadContext.h"
#include "PeerStorage.h"
#include "PieceStorage.h"

namespace aria2 {

ShareRatioSeedCriteria::ShareRatioSeedCriteria
(double ratio, const SharedHandle<DownloadContext>& downloadContext)
  : ratio_(ratio),
    downloadContext_(downloadContext)
{}

ShareRatioSeedCriteria::~ShareRatioSeedCriteria() {}

void ShareRatioSeedCriteria::reset() {}

bool ShareRatioSeedCriteria::evaluate()
{
  uint64_t completedLength = pieceStorage_->getCompletedLength();
  if(completedLength == 0) {
    return true;
  }
  TransferStat stat = peerStorage_->calculateStat();
  return ratio_ <= 1.0*stat.getAllTimeUploadLength()/completedLength;
}


void ShareRatioSeedCriteria::setPeerStorage
(const SharedHandle<PeerStorage>& peerStorage)
{
  peerStorage_ = peerStorage;
}

void ShareRatioSeedCriteria::setPieceStorage
(const SharedHandle<PieceStorage>& pieceStorage)
{
  pieceStorage_ = pieceStorage;
}

} // namespace aria2

==> aria2_1.14.1.orig.tar.bz2: aria2-1.14.1/src/ShareRatioSeedCriteria.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "ShareRatioSeedCriteria.h"
#include "DownloadContext.h"
#include "PeerStorage.h"
#include "PieceStorage.h"

namespace aria2 {

ShareRatioSeedCriteria::ShareRatioSeedCriteria
(double ratio, const SharedHandle<DownloadContext>& downloadContext)
  : ratio_(ratio),
    downloadContext_(downloadContext)
{}

ShareRatioSeedCriteria::~ShareRatioSeedCriteria() {}

void ShareRatioSeedCriteria::reset() {}

bool ShareRatioSeedCriteria::evaluate()
{
  off_t completedLength = pieceStorage_->getCompletedLength();
  if(completedLength == 0) {
    return true;
  }
  TransferStat stat = peerStorage_->calculateStat();
  return ratio_ <= 1.0*stat.getAllTimeUploadLength()/completedLength;
}


void ShareRatioSeedCriteria::setPeerStorage
(const SharedHandle<PeerStorage>& peerStorage)
{
  peerStorage_ = peerStorage;
}

void ShareRatioSeedCriteria::setPieceStorage
(const SharedHandle<PieceStorage>& pieceStorage)
{
  pieceStorage_ = pieceStorage;
}

} // namespace aria2
